<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the PT Course Catalog directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2013.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->

<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	G. Cronkright 
Custom Field Type:
	course_chooser
Name:
	course_chooser_props.cfm
Summary:
	Course Chooser field type.
ADF App
	PT Course Catalog
Version:
	1.0
History:
	2013-01-30 - GAC - Created
--->
<cfscript>
	// initialize some of the attributes variables
	typeid = attributes.typeid;
	prefix = attributes.prefix;
	formname = attributes.formname;
	currentValues = attributes.currentValues;
	
	// Setup the default values
	defaultValues = StructNew();
	
	defaultValues.chooserCFCName = "courseGC";
	defaultValues.forceScripts = "0";
	defaultValues.defaultDeptID = "";
	defaultValues.defaultTermID = "";
	defaultValues.renderDeptFilter = "1";
	defaultValues.renderTermFilter = "1";
	defaultValues.loadAvailable = "0";
	
	//-- App Override Variables --//
	defaultValues.appBeanName = "";
	defaultValues.appPropsVarName = "";
	
	// This will override the current values with the default values.
	// In normal use this should not need to be modified.
	defaultValueArray = StructKeyArray(defaultValues);
	for(i=1;i<=ArrayLen(defaultValueArray);i++){
		// If there is a default value to exists in the current values
		//	AND the current value is an empty string
		//	OR the default value does not exist in the current values
		if( ( StructKeyExists(currentValues, defaultValueArray[i]) 
				AND (NOT LEN(currentValues[defaultValueArray[i]])) )
				OR (NOT StructKeyExists(currentValues, defaultValueArray[i])) ){
			currentValues[defaultValueArray[i]] = defaultValues[defaultValueArray[i]];
		}
	}
</cfscript>
<cfoutput>
	
	<script language="JavaScript" type="text/javascript">
		// register the fields with global props object
		fieldProperties['#typeid#'].paramFields = '#prefix#chooserCFCName,#prefix#forceScripts,#prefix#defaultDeptID,#prefix#defaultTermID,#prefix#renderDeptFilter,#prefix#renderTermFilter,#prefix#loadAvailable,#prefix#appBeanName,#prefix#appPropsVarName';
		// allows this field to support the orange icon (copy down to label from field name)
		fieldProperties['#typeid#'].jsLabelUpdater = '#prefix#doLabel';
		// allows this field to have a common onSubmit Validator
		fieldProperties['#typeid#'].jsValidator = '#prefix#doValidate';
		// handling the copy label function
		function #prefix#doLabel(str)
		{
			document.#formname#.#prefix#label.value = str;
		}
		function #prefix#doValidate(){
			
			// Check the chooserCFCName
			if ( document.getElementById('#prefix#chooserCFCName').value.length <= 0 ) {
				alert("Please enter the Chooser CFC Name property field.");
				return false;
			}
			// Everything is OK, submit form
			return true;
		}
	</script>
	<table>
		<tr valign="top">
			<td class="cs_dlgLabelSmall">Chooser Bean Name:</td>
			<td class="cs_dlgLabelSmall">
				<input type="text" id="#prefix#chooserCFCName" name="#prefix#chooserCFCName" value="#currentValues.chooserCFCName#" size="50"><br />
				Name of the Object Factory Bean that will be rendering and populating the chooser data. (i.e. courseGC). Note: Do NOT include ".cfc" in the name.
			</td>
		</tr>
		<tr>
			<td colspan="2"><hr></td>
		</tr>
		<tr valign="top">
			<td class="cs_dlgLabelSmall">Render Department Filter:</td>
			<td class="cs_dlgLabelSmall">
				<input type="radio" id="#prefix#renderDeptFilter" name="#prefix#renderDeptFilter" value="1" <cfif currentValues.renderDeptFilter EQ 1>checked="checked"</cfif>>Enabled<br />
				<input type="radio" id="#prefix#renderDeptFilter" name="#prefix#renderDeptFilter" value="0" <cfif currentValues.renderDeptFilter EQ 0>checked="checked"</cfif>>Disabled<br />
				Option to enable/disable the department filter selection.
			</td>
		</tr>
		<tr valign="top">
			<td class="cs_dlgLabelSmall">Default Department:</td>
			<td class="cs_dlgLabelSmall">
				<!--- Get the category selections --->
				<cfset deptData = application.ptCourseCatalog.departmentDAO.getDepartments()>
				<select id="#prefix#defaultDeptID" name="#prefix#defaultDeptID">
					<option value=""> - Select Department - </option>
					<cfloop index="dept_i" from="1" to="#arrayLen(deptData)#">
						<option value="#deptData[dept_i].values.uniqueID#"<cfif currentValues.defaultDeptID EQ deptData[dept_i].values.uniqueID> selected="selected"</cfif>>#deptData[dept_i].values.deptName#</option>
					</cfloop>
				</select>
				<br />
				Select the department for the available course selections.<br />
				<!--- If no department is selected, then 'Render Department Filter Option' will be forced enabled. --->
			</td>
		</tr>
		<tr valign="top">
			<td class="cs_dlgLabelSmall">Render Term Filter:</td>
			<td class="cs_dlgLabelSmall">
				<input type="radio" id="#prefix#renderTermFilter" name="#prefix#renderTermFilter" value="1" <cfif currentValues.renderTermFilter EQ 1>checked="checked"</cfif>>Enabled<br />
				<input type="radio" id="#prefix#renderTermFilter" name="#prefix#renderTermFilter" value="0" <cfif currentValues.renderTermFilter EQ 0>checked="checked"</cfif>>Disabled<br />
				Option to enable/disable the term filter selection.
			</td>
		</tr>
		<tr valign="top">
			<td class="cs_dlgLabelSmall">Default Term:</td>
			<td class="cs_dlgLabelSmall">
				<!--- Get the category selections --->
				<cfset termData = application.ptCourseCatalog.termDAO.getTerms()>
				<select id="#prefix#defaultTermID" name="#prefix#defaultTermID">
					<option value=""> - Select Term - </option>
					<cfloop index="term_i" from="1" to="#arrayLen(termData)#">
						<option value="#termData[term_i].values.uniqueID#"<cfif currentValues.defaultDeptID EQ termData[term_i].values.uniqueID> selected="selected"</cfif>>#termData[term_i].values.TermName#</option>
					</cfloop>
				</select>
				<br />
				Select the term for the available course selections.<br />
				<!--- If no term is selected, then 'Render Term Filter Option' will be forced enabled. --->
			</td>
		</tr>
		<tr>
			<td colspan="2"><hr></td>
		</tr>
		<tr valign="top">
			<td class="cs_dlgLabelSmall">Force Loading Scripts:</td>
			<td class="cs_dlgLabelSmall">
				Yes <input type="radio" id="#prefix#forceScripts" name="#prefix#forceScripts" value="1" <cfif currentValues.forceScripts EQ "1">checked</cfif>>&nbsp;&nbsp;&nbsp;
				No <input type="radio" id="#prefix#forceScripts" name="#prefix#forceScripts" value="0" <cfif currentValues.forceScripts EQ "0">checked</cfif>><br />
				Force the JQuery, JQuery UI and ADFlightbox scripts to load.
			</td>
		</tr>
		<tr valign="top">
			<td class="cs_dlgLabelSmall">Load All Available Selections:</td>
			<td class="cs_dlgLabelSmall">
				Yes <input type="radio" id="#prefix#loadAvailable" name="#prefix#loadAvailable" value="1" <cfif currentValues.loadAvailable EQ "1">checked</cfif>>&nbsp;&nbsp;&nbsp;
				No <input type="radio" id="#prefix#loadAvailable" name="#prefix#loadAvailable" value="0" <cfif currentValues.loadAvailable EQ "0">checked</cfif>><br />
				Select the option to load all the avialable selections on the form load.
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall" colspan="2"><hr></td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall" colspan="2">
				<strong>Optional ADF App PROPS Override Settings:</strong>
				<br/><span>(IMPORTANT: If configured correctly these settings will override the entries above!)</span> 
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall" valign="top">App Bean Name:</td>
			<td class="cs_dlgLabelSmall">
				<input type="text" name="#prefix#appBeanName" id="#prefix#appBeanName" class="cs_dlgControl" value="#currentValues.appBeanName#" size="40">
				<br/><span>Please enter the ADF Applications's AppName to override these configuration settings.</span>
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall" valign="top">App Props Variable Name:</td>
			<td class="cs_dlgLabelSmall">
				<input type="text" name="#prefix#appPropsVarName" id="#prefix#appPropsVarName" class="cs_dlgControl" value="#currentValues.appPropsVarName#" size="40">
				<br/><span>Please enter the App Props Variable name that contains PROPS keys and values to override.</span> 
			</td>
		</tr>
	</table>
</cfoutput>