<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the PT Course Catalog directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2013.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
	G. Cronkright
Name:
	schedule_builder_render.cfm
Summary:
	Custom field to build the Date/Time records.
	This field generates a collection of Date and Times for the field.
ADF App:
	PT Course Catalog
Version:
	1.0
History:
	2013-01-30 - GAC - Created
--->
<cfscript>
	// If the ptCourseCatalog bean name has been defined get the app config
	if ( StructKeyExists(application,"ptCourseCatalog") ) {
		// Set the UI theme from the Configuration Element
		uiTheme = application.ptCourseCatalog.getUItheme();
		useDebugOutput = application.ptCourseCatalog.getDebugOutputStatus();
	}
	else {
		uiTheme = "redmond";
		useDebugOutput = false;
	}
//application.ADF.utils.doDUMP(uiTheme,"uiTheme",0);
	
	dtbButtonText = "Add New Date/Time";
	
	dtbController = "scheduleBuilderController";
	dtbService = "scheduleBuilderService";
	dtbForm = "scheduleBuilderForms";

	// the fields current value
	currentValue = attributes.currentValues[fqFieldName];
	
	// the param structure which will hold all of the fields from the props dialog
	xparams = parameters[fieldQuery.inputID];
	
	if ( NOT StructKeyExists(xparams, "fieldID") )
		xparams.fieldID = fqFieldName;
	else
		xparams.fieldID = TRIM(xparams.fieldID);
		
	if ( (NOT StructKeyExists(xparams, "fieldClass")) OR ( LEN(TRIM(xparams.fieldClass)) LTE 0) )
		xparams.fieldClass = "";	
	if ( (NOT StructKeyExists(xparams, "btnText")) OR ( LEN(TRIM(xparams.btnText)) LTE 0) )
		xparams.btnText = dtbButtonText;

	// Get the DateTime element Name
	dtDataElementName = application.ptCourseCatalog.getScheduleCEName();
	// Get the DateTime formid
	dtDataFormID = application.ptCourseCatalog.getScheduleFormID();
	
	// Set the newDefaultPickerDate to be prepared if nothing is passed in 
	newDefaultPickerDate = "";
	
	// Pass new date URL variable through to the Calendar Picker
	if ( StructKeyExists(request.params,"newSelectedDate") AND IsDate(request.params.newSelectedDate) )
		newDefaultPickerDate = request.params.newSelectedDate;	
	
	// Set the the Ajax Loader Image
	ajaxIMG = '<img width="16" height="16" src="/ADF/apps/pt_course_catalog/images/ajax-loader-arrows.gif"/>';
	
	// Create a script obj
	application.ptCourseCatalog.scripts.loadJQuery();
	application.ptCourseCatalog.scripts.loadJQueryUI(themeName=uiTheme);
	application.ptCourseCatalog.scripts.loadADFLightbox();
	
	// Set defaults for the label and description 
	includeLabel = true;
	includeDescription = true; 

	//-- Update for CS 6.x / backwards compatible for CS 5.x --
	//   If it does not exist set the Field Permission variable to a default value
	if ( NOT StructKeyExists(variables,"fieldPermission") )
		variables.fieldPermission = "";

	//-- Read Only Check w/ cs6 fieldPermission parameter --
	readOnly = application.ptCourseCatalog.forms.isFieldReadOnly(xparams,variables.fieldPermission);
</cfscript>

<cfoutput>
	<!--- // Include the app CSS --->
	<link rel="stylesheet" type="text/css" href="/ADF/apps/pt_course_catalog/style/schedule-builder.css">

	<style>
		##form_#fqFieldName# .loading {
			font-size: 12px;
		}
		a.addLink_#fqFieldName# {
			float:right;
			font-size: 10pt;
		}
	</style>
	
	<script>
		// javascript validation to make sure they have text to be converted
		#fqFieldName# = new Object();
		#fqFieldName#.id = '#fqFieldName#';
		#fqFieldName#.tid = '#rendertabindex#';
		#fqFieldName#.validator = "validate_#fqFieldName#()";
		
		#fqFieldName#.msg = "Please add a Date/Time entry.";
		// Check if the field is required
		if ( '#xparams.req#' == 'Yes' ) {
			// push on to validation array
			vobjects_#attributes.formname#.push(#fqFieldName#);
		}
		function validate_#fqFieldName#()
		{
			if (jQuery("input[name=#fqFieldName#]").val() != '')
			{
				return true;
			}
			else{
				//alert(#fqFieldName#.msg);
				return false;
			}
		}
		
		jQuery(function(){
			
			/****************************/
			/*   DOC READY Functions    */
			/****************************/
		
			// Get any Date/Times that have been configured
			reloadDateTimes_#fqFieldName#(0,1);
			
			// addDateTime without action page
			jQuery("##addDateTimeLink_#fqFieldName#").click(function() {
				addDataTime_#fqFieldName#();
			});
			
		});	
		
		/****************************/
		/*      Ajax Functions      */
		/****************************/
			
		// Function to render the links for the record
		function reloadDateTimes_#fqFieldName#(reloadWait,doElementDataSync) {
			reloadWait = typeof reloadWait !== 'undefined' ? reloadWait : 1000;
			doElementDataSync = typeof doElementDataSync !== 'undefined' ? doElementDataSync : true;
			// init the current vals variable
			var currVals = "";
			var buttonText = '#xparams.btnText#';
				
			if ( doElementDataSync ) {
				syncFieldValue_#fqFieldName#();
			}

			// get the current vals				
			//currVals = getCurrentFieldData_#fqFieldName#(); 

			//if ( jQuery.trim(currVals).length ) {
			//	jQuery("##form_#fqFieldName#").html('#ajaxIMG# Loading Scheduled Days and Times...');
			//}
			
			// Display the loading Message
			jQuery("##form_#fqFieldName#").html('<div class="loading">#ajaxIMG# Loading Scheduled Days and Times...</div>');
				
			// Reload the schedule records 
			setTimeout( function() {
					
				// get the current vals	(again to make sure we have update data)			
				currVals = getCurrentFieldData_#fqFieldName#(); 
				getDateTimesHTML_#fqFieldName#(currVals,buttonText);
					
			}, reloadWait );
				
			// Sortable - NOT NEEDED at this time
			//jQuery("##form_#fqFieldName#").sortable({ stop: function(event, ui) { serialize_#fqFieldName#() } });
		}
			
		// Function to render the schedule records
		function getDateTimesHTML_#fqFieldName#(itemIDlist,btnText) {
			itemIDlist = typeof itemIDlist !== 'undefined' ? itemIDlist : "";
			btnText = typeof btnText !== 'undefined' ? btnText : "Add New Item";
				
			// load the html to render the selected items base on a list of items 
			jQuery.get( "#application.ADF.ajaxProxy#",
			{ 	
				bean: "#dtbController#"
				,method: 'renderDateTimeHTML'
				,uuidlist: itemIDlist
				,buttonText: '#xparams.btnText#'	
			},
			function(msg){	
				// Render the Selections Display								
				renderSelectionsDisplayHTML(msg);
			});
		}

		// Use this function to keep event field value and recurrence element values in sync
		function syncFieldValue_#fqFieldName#(){
			// Get the parentID from the uniqueID field from the FORM 
			var parentID = getParentIDFieldData_#fqFieldName#();

			// get the current vals
			jQuery.get("#application.ADF.ajaxProxy#",
				{ 	
					bean: "#dtbService#"
					,method: 'buildDateTimeIDListByParentID'
					,parentID: parentID
				},
				function(data) {	
					// Setthe values of the fqFieldName field 
					setCurrentFieldData_#fqFieldName#(data);
				}
			);
		} 
		
		/****************************/
		/*    Utility Functions     */
		/****************************/
		
		// Function to RETURN the current value that is stored in CFT's hidden field
		function getCurrentFieldData_#fqFieldName#() {
			var retVal = jQuery("input[name=#fqFieldName#]").val();
<cfif useDebugOutput>	
console.log("getCurrentFieldData:");
console.log("retVal: " + retVal);
</cfif>
			return retVal;		
		}
		// Function to RETURN the current value that is stored in CFT's hidden field
		function getParentIDFieldData_#fqFieldName#() {
			var retVal = jQuery("##classID").val();
<cfif useDebugOutput>		
console.log("getParentIDFieldData:");
console.log("retVal: " + retVal);
</cfif>
			return retVal;		
		}
		// Function to SET the current value that is stored in CFT's hidden field
		function setCurrentFieldData_#fqFieldName#(fieldData) {
			jQuery("input[name=#fqFieldName#]").val(fieldData);	
<cfif useDebugOutput>		
console.log("setCurrentFieldData:");
console.log("fieldData: " + fieldData);
</cfif>
		}
		// Function to RENDER the current selection list UI display
		function renderSelectionsDisplayHTML(htmlData) {
			jQuery("##form_#fqFieldName#").html(htmlData);
<cfif useDebugOutput>	
console.log("renderSelectionsDisplayHTML:");
console.log("htmlData: " + htmlData);
</cfif>
			// Load the click handlers for the datetime edit/delete links
			loadActionButtons_#fqFieldName#();
				
			// Resize Lightbox window
			if ( typeof lbResizeWindow == 'function' )
				lbResizeWindow();
			else if ( typeof ResizeWindow == 'function' )
				ResizeWindow();		
		}
		// Function to load Events with edit and delete links 
		function loadActionButtons_#fqFieldName#() {
			jQuery("a.date-time-builder-edit").click(function() { 
		    	var currUUID = jQuery(this).attr("id");
		    	editDateTime_#fqFieldName#(currUUID);
		    });
			    
		    jQuery("a.date-time-builder-remove").click(function() { 
		    	var currUUID = jQuery(this).attr("id");
		    	removeDateTime_#fqFieldName#(currUUID);
		    });
			    
		    // Hover states on the static widgets
			jQuery("div.date-time-builder-block div.ui-button").hover(
				function() { 
					jQuery(this).css("cursor", "hand");
					jQuery(this).addClass("ui-state-hover");
				},
				function() { 
					jQuery(this).css("cursor", "pointer");
					jQuery(this).removeClass('ui-state-hover');
				}
			);
		}
		// Serialize the selections 
		function serialize_#fqFieldName#() {
			// load current values into the form field
			jQuery("input[name=#fqFieldName#]").val(jQuery('##form_#fqFieldName#').sortable( 'toArray' ));
		}
			
		/****************************/
		/*    CallBack Functions    */
		/****************************/
			
		function addEdit_cbFunct_#fqFieldName#(inArgsArray) {
			var newUUID = inArgsArray[0];
			var parentID = inArgsArray[1];
			var action = inArgsArray[2];
				
			// Get the current values from the fqFieldName field 
			var currVals = getCurrentFieldData_#fqFieldName#();
				
			// Update the fqFieldName field with the new UUID
			jQuery.get( "#application.ADF.ajaxProxy#", { 	
				bean: "#dtbService#",
				method: 'listManagement',
				currList: currVals,
				currItem: newUUID,
				actionType: action
			},
			function(data){

				// Get the values of the fqFieldName field 
				setCurrentFieldData_#fqFieldName#(data);
					
				// Reload the schedule records
				reloadDateTimes_#fqFieldName#(2000);
					
			});
		}
			
		// Function for the remove links callback
		function remove_cbFunct_#fqFieldName#(cbValues){
			// Close the current LB layer for the delete form
			closeLB();
			// Set the list management action
			var action = 'remove';
			// Set the RemoveID value from the passed in cbIDlist
			var removeID = "";
				
			if ( cbValues.hasOwnProperty("cbIDlist") ) 
				removeID = cbValues.cbIDlist;
				
			// Get the current values from the fqFieldName field 
			var currVals = getCurrentFieldData_#fqFieldName#();
							
			// Update the field and then re-render the display
			jQuery.get( "#application.ADF.ajaxProxy#", { 	
				bean: "#dtbService#",
				method: 'listManagement',
				currList: currVals,
				currItem: removeID,
				actionType: action
			},
			function(data){
				// Set the value back into the save field
				setCurrentFieldData_#fqFieldName#(data);
				// Reload the render dateTime blocks
				reloadDateTimes_#fqFieldName#();
			});
		}
			
		/****************************/
		/*    UI Button Functions   */
		/****************************/
			
		// Function to open form to create new dateTime entries
		function addDataTime_#fqFieldName#(){
			// Get the parentID from the uniqueID field from the FORM 
			var parentID = getParentIDFieldData_#fqFieldName#();
			<!--- // If a new default date picker date is passed in add that to the URL parameters --->
			<cfif LEN(TRIM(newDefaultPickerDate))>	
			openLB("#application.ADF.lightboxProxy#?bean=#dtbForm#&method=renderDateTimeForm&dataPageID=0&parentID=" + parentID + "&callback=addEdit_cbFunct_#fqFieldName#&title=Add Date/Time&newSelectedDate=#newDefaultPickerDate#"); 
			<cfelse>
			openLB("#application.ADF.lightboxProxy#?bean=#dtbForm#&method=renderDateTimeForm&dataPageID=0&parentID=" + parentID + "&callback=addEdit_cbFunct_#fqFieldName#&title=Add Date/Time"); 
			</cfif>
		}
	
		// Function to open form to edit dateTime entries
		function editDateTime_#fqFieldName#(datetimeid) {
			// Get the parentID from the uniqueID field from the FORM 
			var parentID = getParentIDFieldData_#fqFieldName#();
			openLB("#application.ADF.lightboxProxy#?bean=#dtbForm#&method=renderDateTimeForm&dateTimeID=" + datetimeid + "&parentID=" + parentID + "&callback=addEdit_cbFunct_#fqFieldName#&title=Edit Date/Time");
		}
			
		function removeDateTime_#fqFieldName#(datetimeid) {
			openLB("#application.ADF.lightboxProxy#?bean=#dtbForm#&method=renderDateTimeDeleteForm&dateTimeID=" + datetimeid + "&callback=remove_cbFunct_#fqFieldName#&cbIDlist=" + datetimeid + "&title=Delete Date/Time");
		}
	</script>
	
	<!--- // Build the field inner HTML --->
	<cfsavecontent variable="inputHTML">
		<cfoutput>
			<!--- <cfdump var="#currentValue#" expand=false label=false> --->
			<div class="date-time-builder-block">
				<!--- // - Display the open dateTime builder Button  --->
				<div id="addDateTimeLink_#fqFieldName#" class="ui-button ui-state-default ui-corner-all">#xparams.btnText#</div>
				<div style="clear: both;"></div>
				<!--- // DIV where DateTime blocks are loaded --->
				<div id="form_#fqFieldName#"></div>
				<!--- hidden field to store the value --->
				<input type="hidden" name="#fqFieldName#" value="#currentValue#" id="#xparams.fieldID#" class="#xparams.fieldClass#" size="40">
			</div>
		</cfoutput>
	</cfsavecontent>
	<!--- Pass inner html to the wrapper function to format the CFT --->
	#application.ADF.forms.wrapFieldHTML(inputHTML,fieldQuery,attributes,variables.fieldPermission,includeLabel,includeDescription)#
</cfoutput>